Perf Report

# Performance Report

## run_id: 20251126T065306Z

## seed_data_rows: 10000000

## [TEST bulk create from schemas]

## [TEST bulk update from dict]

## [TEST paging (page size: 1000) with ORDER BY ID- keyset]

## [TEST paging (page size: 1000) with ORDER BY ID- offset]

## [TEST fetch with 3 WHERE and 3 ORDER BY Conditions]

## [TEST fetch with 8 ORDER By Conditions]

## [TEST fetch with 8 WHERE Conditions]